# OrganisationResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**organisation_reference** | **str** |  | 
**organisation_status** | **AllOfOrganisationResponseOrganisationStatus** |  | [optional] 
**organisation_status_string** | **str** |  | [optional] 
**address_line_one** | **str** |  | 
**address_line_two** | **str** |  | [optional] 
**email** | **str** |  | [optional] 
**locality** | **str** |  | [optional] 
**phone_number** | **str** |  | 
**postcode** | **str** |  | 
**town** | **str** |  | [optional] 
**prefix** | **str** |  | 
**organisation_type** | [**OrganisationTypeResponse**](OrganisationTypeResponse.md) |  | 
**organisation_type_string** | **str** |  | 
**contractors** | [**list[OrganisationSummaryResponse]**](OrganisationSummaryResponse.md) |  | [optional] 
**is_hs2_applicable** | **bool** |  | 
**primary_contact_name** | **str** |  | [optional] 
**primary_contact_email** | **str** |  | [optional] 
**primary_contact_number** | **str** |  | [optional] 
**primary_admin_name** | **str** |  | [optional] 
**primary_admin_email** | **str** |  | [optional] 
**primary_admin_number** | **str** |  | [optional] 
**industry_sector** | **AllOfOrganisationResponseIndustrySector** |  | [optional] 
**industry_sector_string** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

